@@ -8,7 +8,7 @@ use Moo;
 use MooX::StrictConstructor;
 use namespace::autoclean;
 
-our $VERSION = '1.026';
+our $VERSION = '1.027';
 
 with qw(
     Locale::TextDomain::OO::Lexicon::Role::File
@@ -58,13 +58,13 @@ __END__
 
 Locale::TextDomain::OO::Lexicon::File::PO - Gettext po file as lexicon
 
-$Id: PO.pm 546 2014-10-31 09:35:19Z steffenw $
+$Id: PO.pm 647 2017-02-25 08:22:10Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Lexicon/File/PO.pm $
 
 =head1 VERSION
 
-1.026
+1.027
 
 =head1 DESCRIPTION
 
@@ -73,6 +73,7 @@ This module reads a gettext po file into the lexicon.
 =head1 SYNOPSIS
 
     use Locale::TextDomain::OO::Lexicon::File::PO;
+    use Log::Any qw($log);
 
     Locale::TextDomain::OO::Lexicon::File::PO
         ->new(
@@ -87,7 +88,7 @@ This module reads a gettext po file into the lexicon.
             logger => sub {
                 my ($message, $arg_ref) = @_;
                 my $type = $arg_ref->{type}; # debug
-                Log::Log4perl->get_logger(...)->$type($message);
+                $log->$type($message);
                 return;
             },
         )
@@ -149,7 +150,7 @@ Set the logger
         sub {
             my ($message, $arg_ref) = @_;
             my $type = $arg_ref->{type};
-            Log::Log4perl->get_logger(...)->$type($message);
+            $log->$type($message);
             return;
         },
     );
@@ -201,7 +202,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2014,
+Copyright (c) 2014 - 2017,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
