@@ -4,9 +4,8 @@ use strict;
 use warnings;
 use Locale::Utils::PlaceholderNamed;
 use Moo::Role;
-use namespace::autoclean;
 
-our $VERSION = '1.014';
+our $VERSION = '1.027';
 
 requires qw(
     translate
@@ -113,7 +112,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk
 
 =head1 VERSION
 
-1.014
+1.027
 
 =head1 DESCRIPTION
 
@@ -336,8 +335,6 @@ L<Locale::Utils::PlaceholderNamed|Locale::Utils::PlaceholderNamed>
 
 L<Moo::Role|Moo::Role>
 
-L<namespace::autoclean|namespace::autoclean>
-
 =head1 INCOMPATIBILITIES
 
 not known
@@ -356,7 +353,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009 - 2014,
+Copyright (c) 2009 - 2017,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
