@@ -5,9 +5,8 @@ use warnings;
 use Carp qw(confess cluck);
 use Locale::Utils::PlaceholderNamed;
 use Moo::Role;
-use namespace::autoclean;
 
-our $VERSION = '1.014';
+our $VERSION = '1.027';
 
 with qw(
     Locale::TextDomain::OO::Plugin::Expand::Gettext
@@ -285,7 +284,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk
 
 =head1 VERSION
 
-1.014
+1.027
 
 =head1 DESCRIPTION
 
@@ -411,8 +410,6 @@ L<Locale::Utils::PlaceholderNamed|Locale::Utils::PlaceholderNamed>
 
 L<Moo::Role|Moo::Role>
 
-L<namespace::autoclean|namespace::autoclean>
-
 L<Locale::TextDomain::OO::Plugin::Expand::Gettext|Locale::TextDomain::OO::Plugin::Expand::Gettext>
 
 =head1 INCOMPATIBILITIES
@@ -433,7 +430,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2013,
+Copyright (c) 2013 - 2017,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
